/*  smplayer, GUI front-end for mplayer.
    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _GUI_H_
#define _GUI_H_

#include "guibase.h"
#include "mediadata.h"
#include "mediasettings.h"
#include "preferences.h"
#include "core.h"
#include "config.h"
#include "recents.h"

class QPopupMenu;
class QTextBrowser;
class LogWindow;
class MplayerWindow;
class QGridLayout;
class QLabel;
class PreferencesDialog;
class FilePreferencesDialog;
class Keys;
class VideoEqualizer;
class Playlist;
class QDockWindow;
class InfoWindow;

class Gui : public GuiBase
{
    Q_OBJECT
    
public:
    Gui( QWidget* parent = 0, const char* name = 0, WFlags fl = WType_TopLevel );
    ~Gui();
    
public slots:
	virtual void open(QString file); // Generic open, autodetect type.
    virtual void openFile();
	virtual void openFile(QString file);
	virtual void openURL();
	virtual void openURL(QString url);
	virtual void openDVD();
	virtual void openDVDFromFolder();
	virtual void openDVDFromFolder(QString directory);
	virtual void openDirectory();
	virtual void openDirectory(QString directory);

    virtual void helpAbout();
	virtual void helpAboutQt();
    virtual void loadSub();

	virtual void showPlaylist();
	virtual void showEqualizer();
	virtual void showMplayerLog();
    virtual void showLog();
	virtual void showInfo();
	virtual void showPreferencesDialog();
	virtual void showFilePreferencesDialog();

	virtual void toggleFullscreen();
    virtual void toggleFullscreen(bool);

	virtual void toggleCompactMode();
	virtual void toggleCompactMode(bool);

protected slots:
	virtual void openRecent(int item);
	virtual void enterFullscreen();
	virtual void exitFullscreen();
	virtual void exitFullscreenIfNeeded();

	virtual void displayTime(double sec);
    virtual void displayState(int state);
	virtual void displayMessage(QString message);

    virtual void initializeMenus();
	virtual void updateWidgets();
	virtual void updateEqualizer();
	virtual void updatePlaylistButton();
	virtual void updateMediaInfo();
	virtual void resizeWindow(int w, int h);
	virtual void hidePanel();

	virtual void displayGotoTime(int);

	virtual void showPopupMenu( QPoint p );
	virtual void mouseReleaseEvent( QMouseEvent * e );
	virtual void wheelEvent( QWheelEvent * e ) ;
	virtual void keyPressEvent( QKeyEvent *e );
	virtual void dragEnterEvent( QDragEnterEvent * ) ;
	virtual void dropEvent ( QDropEvent * );

	virtual void applyNewPreferences();
	virtual void applyFilePreferences();

	// Only for FULLSCREEN_WITH_MAINWINDOW
	// Can't set a define here
	virtual void checkMousePos( QPoint );

signals:
	virtual void wheelUp();
	virtual void wheelDown();
    
protected:
	virtual void createMenus();
	virtual void connectWidgets();
	virtual void updateRecents();
	virtual void closeEvent( QCloseEvent * e );

protected:
	QPopupMenu *openMenu;
    QPopupMenu *playMenu;
    QPopupMenu *videoMenu;
    QPopupMenu *audioMenu;
    QPopupMenu *subtitlesMenu;
    QPopupMenu *browseMenu;
    QPopupMenu *optionsMenu;
    QPopupMenu *helpMenu;

    QPopupMenu * subtitlestrack_menu;
	QPopupMenu * audiotrack_menu;
	QPopupMenu * titles_menu;
	QPopupMenu * chapters_menu;
	QPopupMenu * angles_menu;
	QPopupMenu * aspect_menu;
	QPopupMenu * osd_menu;
	QPopupMenu * deinterlace_menu;
	QPopupMenu * audiofilter_menu;
	QPopupMenu * videofilter_menu;
	QPopupMenu * audiochannels_menu;
	QPopupMenu * stereomode_menu;
	QPopupMenu * logs_menu;
	QPopupMenu * speed_menu;
	//QPopupMenu * preferences_menu;
	QPopupMenu * popup;
	QPopupMenu * recentfiles_menu;
    
    LogWindow * mplayer_log_window;
    LogWindow * smplayer_log_window;
	InfoWindow * info_window;
	QLabel * time_display;

	PreferencesDialog *pref_dialog;
	FilePreferencesDialog *file_dialog;
	Playlist * playlist;
	QDockWindow * playlistdock;
	VideoEqualizer * equalizer;

	Core * core;
    MplayerWindow *mplayerwindow;
    QGridLayout* panelLayout;

	Keys * kl;

	// Fullscreen widget
	QWidget * fullscreen_widget;
    QGridLayout* fullscreen_widget_layout;

	Recents recents;

private:
	int last_second;
	QString default_style;
};
    
#endif

