/*  smplayer, GUI front-end for mplayer.
    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _PREFERENCES_DIALOG_H_
#define _PREFERENCES_DIALOG_H_

#include "preferencesdialogbase.h"
#include "inforeader.h"
#include "config.h"

class Encodings;

class PreferencesDialog : public PreferencesDialogBase
{
	Q_OBJECT

public:
	PreferencesDialog( QWidget* parent = 0, const char* name = 0, bool modal  = FALSE, WFlags fl = 0 );
    ~PreferencesDialog();

	// Call it as soon as possible
	void setDrivers(InfoList vo_list, InfoList ao_list);
	bool hasDriversList() { return drivers_set; };

	// General Page
	void setMplayerPath( QString path );
	QString mplayerPath();

	void setScreenshotDir( QString path );
	QString screenshotDir();

	void setVO( QString vo_driver );
	QString VO();

	void setAO( QString ao_driver );
	QString AO();

	void setEq2(bool b);
	bool eq2();

	void setSoftVol(bool b);
	bool softVol();

	void setRememberSettings(bool b);
	bool rememberSettings();

	void setDontRememberTimePos(bool b);
	bool dontRememberTimePos();

	void setStartInFullscreen(bool b);
	bool startInFullscreen();

	// Drive page
	void setDVDDevice( QString dir );
	QString dvdDevice();

	void setCDRomDevice( QString dir );
	QString cdromDevice();

	// Misc Page
	void setDisableScreensaver(bool b);
	bool disableScreensaver();

	void setResizeMethod(int v);
	int resizeMethod();

	void setWheelSeek(int secs);
	int wheelSeek();

	void setMonitorAspect(QString asp);
	QString monitorAspect();

	void setStyle(QString style);
	QString style();

	// Subtitle Page
	void setFontName(QString font_name);
	QString fontName();

	void setFontFile(QString font_file);
	QString fontFile();

	void setUseFontconfig(bool b);
	bool useFontconfig();

	void setFontAutoscale(int n);
	int fontAutoscale();

	void setFontTextscale(int n);
	int fontTextscale();

	void setAutoloadSub(bool v);
	bool autoloadSub();

	void setFontEncoding(QString s);
	QString fontEncoding();

	void setUseFontASS(bool v);
	bool useFontASS();

	void setAssColor( unsigned int color );
	unsigned int assColor();

	void setAssBorderColor( unsigned int color );
	unsigned int assBorderColor();

	void setFontFuzziness(int n);
	int fontFuzziness();

	// MPlayer Page
	void setUseMplayerWindow(bool v);
	bool useMplayerWindow();

	void setMplayerAdditionalArguments(QString args);
	QString mplayerAdditionalArguments();

	void setMplayerAdditionalVideoFilters(QString s);
	QString mplayerAdditionalVideoFilters();

	void setMplayerAdditionalAudioFilters(QString s);
	QString mplayerAdditionalAudioFilters();

	// Performance Page
	void setCache(int n);
	int cache();

	void setPriority(int n);
	int priority();

	void setFrameDrop(bool b);
	bool frameDrop();

	void setHardFrameDrop(bool b);
	bool hardFrameDrop();

	void setAutoq(int n);
	int autoq();

	void setAutoSyncFactor(int factor);
	int autoSyncFactor();
	void setAutoSyncActivated(bool b);
	bool autoSyncActivated();

	void setFastChapterSeeking(bool b);
	bool fastChapterSeeking();

	void setFastAudioSwitching(bool b);
	bool fastAudioSwitching();

protected slots:
	void changeSection(int);

	void autoSyncButtonToggled(bool);

	void systemFontRadioButtonSelected();
	void ttfFontRadioButtonSelected();
	void assButtonToggled(bool);
	void rememberAllButtonToggled(bool);

	void selectSystemFont();
	void selectTtfFont();
	void selectAssColor();
	void selectAssBorderColor();

	void selectMplayerPath();
	void selectScreenshotDirectory();

	// Reimplemented to send a signal
	void accept();
	void apply();

signals:
	void applyButtonPressed();

protected:
	Encodings * encodings;
	bool drivers_set;
	unsigned int ass_color, ass_border_color;
};


#endif
